MiniAVMouseButton enum

Inheritance
Available extensions

Values

none → const MiniAVMouseButton
const MiniAVMouseButton(0)
left → const MiniAVMouseButton
const MiniAVMouseButton(1)
const MiniAVMouseButton(2)
middle → const MiniAVMouseButton
const MiniAVMouseButton(3)
x1 → const MiniAVMouseButton
const MiniAVMouseButton(4)
x2 → const MiniAVMouseButton
const MiniAVMouseButton(5)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) MiniAVMouseButton

Constants

values → const List<MiniAVMouseButton>
A constant List of the values in this enum, in order of their declaration.