MiniAVVideoInfo class
Constructors
- MiniAVVideoInfo({required int width, required int height, required MiniAVPixelFormat pixelFormat, required int frameRateNumerator, required int frameRateDenominator, required MiniAVOutputPreference outputPreference})
Properties
- frameRateDenominator → int
-
final
- frameRateNumerator → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
final
- outputPreference → MiniAVOutputPreference
-
final
- pixelFormat → MiniAVPixelFormat
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited